@@ -73,7 +73,10 @@ def main():
               'pov': d.gamestate.clientNum,
               'timestamp': time.ctime(float(d.gamestate.config['serverinfo']['g_levelStartTime'])),
               'mapname': d.gamestate.config['serverinfo']['mapname'],
-              'duration': duration}
+              'duration': duration,
+              'server': {'hostname': d.gamestate.config['serverinfo']['sv_hostname'],
+                         'location': d.gamestate.config['serverinfo']['sv_location']}
+          }
 
     #output['scores'] = d.scores[-1] if d.scores else {}
     output['scores'] = {}
